==> nextcloud-app-notes-4.8.1-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/notes/l10n/uk.js <==
OC.L10N.register(
    "notes",
    {
    "Notes" : "Нотатки",
    "Create new note" : "Створити нову нотатку",
    "More notes" : "Більше нотаток",
    "Reading notes from filesystem has failed." : "Не вдалося прочитати нотатки з файлової системи.",
    "Error" : "Помилка",
    "New note" : "Нова нотатка",
    "Distraction-free notes and writing" : "Нотатки та записи без відволікань",
    "Notes settings" : "Налаштування",
    "Please see Nextcloud server log for details." : "Будь ласка, перегляньте журнал сервера Nextcloud для отримання додаткової інформації.",
    "Deleted {title}" : "Вилучено {title}",
    "Undo Delete" : "Повернути вилучення",
    "Note recovered" : "Примітку відновлено",
    "There are unsaved notes. Leaving the page will discard all changes!" : "Є незбережені нотатки. Якщо залишити сторінку, усі зміни буде скасовано!",
    "_Deleted {number} note_::_Deleted {number} notes_" : ["Видалено {number} примітка","Видалено {number} приміток","Видалено {number} приміток","Видалено {number} приміток"],
    "_Recovered {number} note_::_Recovered {number} notes_" : ["Відновлено {number} нотатка","Відновлено {number} нотаток","Відновлено {number} нотаток","Відновлено {number} нотаток"],
    "Basics" : "Простий",
    "Write down your thoughts without any distractions." : "Записуйте свої думки, не відволікаючись.",
    "Organize your notes in categories." : "Упорядкуйте нотатки за категоріями.",
    "Notes path" : "Шлях до нотаток",
    "Folder to store your notes" : "Каталог для збереження нотаток",
    "Root directory" : "Кореневий каталог",
    "File extension" : "Розширення файлу",
    "File extension for new notes" : "Розширення файлу для нових нотаток",
    "Display mode" : "Режим перегляду",
    "Display mode for notes" : "Показувати нотатки",
    "Shortcuts" : "Скорочення",
    "Use shortcuts to quickly navigate this app." : "Використовуйте скорочення для швидкої навігації у цьому застосунку.",
    "Shortcut" : "Скорочення",
    "Action" : "Дія ",
    "Mobile apps" : "Мобільні застосунки",
    "User defined" : "Визначений користувачем",
    "Open in rich text mode" : "Відкрити у форматованому режимі",
    "Open in edit mode" : "Відкривати у режимі редагування",
    "Open in preview mode" : "Відкривати у режимі перегляду",
    "CTRL" : "CTRL",
    "Make the selection bold" : "Зробити виділене грубим",
    "Make the selection italic" : "Зробити виділене курсивом",
    "Wrap the selection in quotes" : "Додати лапки до виділеного фрагменту",
    "ALT" : "ALT",
    "The selection will be turned into monospace" : "Перетворити шрифт виділеного тексту у моноширинний",
    "Remove any styles from the selected text" : "Прибрати стилі з виділеного тексту",
    "Makes the current line a list element" : "Зробити рядок елементом списку",
    "Makes the current line a list element with a number" : "Зробити рядок елементом нумерованого списку",
    "Toggle heading for current line" : "Зробити рядок заголовком",
    "SHIFT" : "SHIFT",
    "Set the current line as a big heading" : "Зробити рядок великим заголовком",
    "Insert link" : "Вставити посилання",
    "Insert image" : "Додати зображення",
    "Switch between editor and viewer" : "Перемкнути редактор та переглядач",
    "Select folder to link to" : "Виберіть каталог",
    "All notes" : "Усі нотатки",
    "Categories" : "Категорії",
    "Create a sample note with Markdown" : "Створіть зразок примітки з Markdown",
    "No notes yet" : "Нотатки поки відсутні",
    "Upload image" : "Завантажити зображення",
    "Select an image" : "Виберіть зображення",
    "You cannot select images outside of your notes folder. Your notes folder is: {folder}" : "Ви не можете вибрати зображення за межами каталогу з нотатками. Ваш каталог нотаток: {folder}",
    "Wrong image" : "Недійсне зображення",
    "The file was not uploaded. Check your server logs." : "Файл не було завантажено. Перевірте журнали свого сервера.",
    "Install the app for your mobile phone in order to access your notes from everywhere." : "Встановіть програму для свого мобільного телефону, щоб мати доступ до своїх нотаток звідусіль.",
    "Android app: {notes}" : "Додаток для Android: {notes}",
    "iOS app: {notes}" : "Додаток для iOS: {notes}",
    "Rich text editor" : "Редактор з форматуванням",
    "You can now switch to use the easy to use and distraction free rich text editor. It allows you to edit notes without seeing any Markdown marks." : "Ви можете почати використовувати простий у користуванні редактор форматованого тексту, який дозволить вводити текст без службових символів позначення форматування.",
    "This option can also be changed later on in the Notes app settings." : "Цю опцію можна буде змінити пізніше у налаштуваннях Нотаток.",
    "Keep plain Markdown editor" : "Використовувати простий редактор розмітки",
    "Use rich editor" : "Використовувати редактор з форматуванням",
    "Details" : "Деталі",
    "Delete note" : "Вилучити нотатку",
    "Remove from favorites" : "Вилучено з улюбленого",
    "Add to favorites" : "Додати зірочку",
    "Error during preparing note for deletion." : "Помилка під час підготовки нотатки до вилучення.",
    "The note has been changed in another session. Please choose which version should be saved." : "Нотатку було змінено в іншому сеансі. Будь ласка, виберіть, яку версію потрібно зберегти.",
    "Use version from server" : "Використовуйте віддалену версію",
    "Use current version" : "Використовувати поточну версію",
    "Empty note" : "Порожня записка",
    "Write …" : "Напишіть…",
    "CTRL + /" : "CTRL + /",
    "Edit" : "Редашувати",
    "Preview" : "Перегляд",
    "Exit full screen" : "Вийти з повноекранного режиму",
    "Full screen" : "Повноекранний режим",
    "Note is read-only. You cannot change it." : "Примітка доступна лише для читання. Ви не можете це змінити.",
    "Save failed. Click to retry." : "Не вдалося зберегти. Натисніть, щоб повторити спробу.",
    "Update conflict. Click for resolving manually." : "Конфлікт оновлень. Натисніть, щоб вирішити вручну.",
    "Error from Nextcloud server: {msg}" : "Помилка сервера Nextcloud: {msg}",
    "Search for notes" : "Пошук нотаток",
    "Loading …" : "Завантаження...",
    "Find in all categories" : "Шукати в усіх категоріях",
    "Today" : "Сьогодні",
    "Yesterday" : "Вчора",
    "This week" : "Цього тижня",
    "Last week" : "Минулого тижня",
    "This month" : "Цього місяця",
    "Last month" : "Минулого місяця",
    "Category" : "Категорія",
    "Uncategorized" : "Некатегоризоване",
    "Set category" : "Встановити категорію",
    "Click here to save manually" : "Натисніть тут, щоб зберегти вручну",
    "Saving failed!" : "Не вдалося зберегти!",
    "Last modified: {date}" : "Остання зміна: {дата}",
    "Note has unsaved changes" : "Примітка містить незбережені зміни",
    "Subcategory" : "Підкатегорія",
    "Click to edit title" : "Натисніть, щоб змінити заголовок",
    "_%n word_::_%n words_" : ["%n слово","%n слів","%n слів","%n слів"],
    "_%n character_::_%n characters_" : ["%n персонаж","%n персонажів","%n персонажів","%n персонажів"],
    "Use Markdown markups to style your text." : "Використовуйте розмітку Markdown, щоб стилізувати текст.",
    "Start writing a note by clicking on “{newnote}” in the app navigation." : "Почніть писати нотатку, натиснувши «{newnote}» ​​у навігаційній панелі програми.",
    "You can create subcategories by using “/” as delimiter between parent category and subcategory, e.g. “{parent}/{sub}”." : "Ви можете створювати підкатегорії із застосуванням \"/\" як роздільника між батьківською категорією та підкатегорією, наприклад. \"{parent}/{sub}\".",
    "Note not found." : "Примітка не знайдена.",
    "Note is locked." : "Примітка заблокована.",
    "Insufficient storage." : "Недостатньо місця для зберігання.",
    "See JavaScript console and server log for details." : "Додаткову інформацію див. у консолі JavaScript і журналі сервера.",
    "Updating settings has failed." : "Не вдалося оновити налаштування.",
    "Fetching notes for dashboard has failed." : "Не вдалося отримати нотатки для інформаційної панелі.",
    "Fetching notes has failed." : "Помилка отримання нотаток.",
    "Fetching note {id} has failed." : "Не вдалося отримати нотатку {id}.",
    "Refreshing note {id} has failed." : "Не вдалося оновити нотатку {id}.",
    "Renaming note {id} has failed." : "Не вдалося перейменувати нотатку {id}.",
    "Creating new note has failed." : "Не вдалося створити нотатку.",
    "Saving note {id} has failed." : "Не вдалося зберегти нотатку {id}.",
    "Updating title for note {id} has failed." : "Помилка оновлення назви нотатки {id}.",
    "Undo delete has failed for note {title}." : "Не вдалося скасувати вилучення нотатки {title}.",
    "Deleting note {id} has failed." : "Не вдалося вилучити нотатку {id}.",
    "Toggling favorite for note {id} has failed." : "Помилка перемикання вподобаних нотаток {id}.",
    "Updating the note's category has failed. Is the target directory writable?" : "Не вдалося оновити категорію нотатки. Чи доступний цільовий каталог для запису?",
    "Updating the category for note {id} has failed." : "Не вдалося оновити категорію для примітки {id}.",
    "Sample note" : "Приклад нотатки",
    "15 January 2021, via Nextcloud Notes" : "15 січня 2021 р., у Нотатках Nextcloud",
    "Me, you, and all our friends!" : "Я, ти та всі наші друзі!",
    "Tasks" : "Завдання",
    "Write nice todo lists" : "Написати зручний список справ",
    "Buy Fries" : "Купити пиріжків",
    "Birthdays" : "Дні народження",
    "Jen, in three days!" : "Петро, через три дні!",
    "Moss, 21.03.1973" : "Іванка, 21.03.1973",
    "Roy, 1979" : "Роман, 1979",
    "Review Steps" : "Переглянути послідовність кроків",
    "Turn PC off" : "Вимкнути комп'ютер",
    "Turn PC on" : "Увімкнути комп'ютер",
    "Then call IT" : "Далі зателефонуйте до служби підтримки",
    "Quotes" : "Цитати",
    "Nextcloud, a safe home for all your data" : "Хмара у Nextcloud, безпечний простір для ваших даних",
    "Development Mode" : "Режим розробки",
    "It looks that the notes app was installed from a development source. Please install it from the official <a href=\"%1$s\">Nextcloud App Store</a> instead. If you want to build the Notes app by yourself, please follow the <a href=\"%2$s\">developer instructions</a>." : "Схоже, застосунок для нотаток було встановлено з джерела розробки. Установіть його з офіційного <a href=\"%1$s\">каталогу застосунків Nextcloud</a>. Якщо ви хочете збілдити застосунок \"Нотатки\" самостійно, дотримуйтесь <a href=\"%2$s\">інструкцій розробника</a>."
},
"nplurals=4; plural=(n % 1 == 0 && n % 10 == 1 && n % 100 != 11 ? 0 : n % 1 == 0 && n % 10 >= 2 && n % 10 <= 4 && (n % 100 < 12 || n % 100 > 14) ? 1 : n % 1 == 0 && (n % 10 ==0 || (n % 10 >=5 && n % 10 <=9) || (n % 100 >=11 && n % 100 <=14 )) ? 2: 3);");

==> nextcloud-app-notes-4.9.2-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/notes/l10n/uk.js <==
OC.L10N.register(
    "notes",
    {
    "Notes" : "Нотатки",
    "Create new note" : "Створити нову нотатку",
    "More notes" : "Більше нотаток",
    "Reading notes from filesystem has failed." : "Не вдалося прочитати нотатки з файлової системи.",
    "Error" : "Помилка",
    "New note" : "Нова нотатка",
    "Distraction-free notes and writing" : "Нотатки та записи без відволікань",
    "Notes settings" : "Налаштування",
    "Please see Nextcloud server log for details." : "Будь ласка, перегляньте журнал сервера Nextcloud для отримання додаткової інформації.",
    "Deleted {title}" : "Вилучено {title}",
    "Undo Delete" : "Повернути вилучення",
    "Note recovered" : "Примітку відновлено",
    "There are unsaved notes. Leaving the page will discard all changes!" : "Є незбережені нотатки. Якщо залишити сторінку, усі зміни буде скасовано!",
    "_Deleted {number} note_::_Deleted {number} notes_" : ["Видалено {number} примітка","Видалено {number} приміток","Видалено {number} приміток","Видалено {number} приміток"],
    "_Recovered {number} note_::_Recovered {number} notes_" : ["Відновлено {number} нотатка","Відновлено {number} нотаток","Відновлено {number} нотаток","Відновлено {number} нотаток"],
    "Basics" : "Простий",
    "Write down your thoughts without any distractions." : "Записуйте свої думки, не відволікаючись.",
    "Organize your notes in categories." : "Упорядкуйте нотатки за категоріями.",
    "Notes path" : "Шлях до нотаток",
    "Folder to store your notes" : "Каталог для збереження нотаток",
    "Root directory" : "Кореневий каталог",
    "File extension" : "Розширення файлу",
    "File extension for new notes" : "Розширення файлу для нових нотаток",
    "Display mode" : "Режим перегляду",
    "Display mode for notes" : "Показувати нотатки",
    "Shortcuts" : "Скорочення",
    "Use shortcuts to quickly navigate this app." : "Використовуйте скорочення для швидкої навігації у цьому застосунку.",
    "Shortcut" : "Скорочення",
    "Action" : "Дія ",
    "Mobile apps" : "Застосунки",
    "User defined" : "Визначений користувачем",
    "Open in rich text mode" : "Відкривати у форматі текстової розмітки",
    "Open in edit mode" : "Відкривати у режимі редагування",
    "Open in preview mode" : "Відкривати у режимі перегляду",
    "CTRL" : "CTRL",
    "Make the selection bold" : "Зробити виділене грубим",
    "Make the selection italic" : "Зробити виділене курсивом",
    "Wrap the selection in quotes" : "Додати лапки до виділеного фрагменту",
    "ALT" : "ALT",
    "The selection will be turned into monospace" : "Перетворити шрифт виділеного тексту у моноширинний",
    "Remove any styles from the selected text" : "Прибрати стилі з виділеного тексту",
    "Makes the current line a list element" : "Зробити рядок елементом списку",
    "Makes the current line a list element with a number" : "Зробити рядок елементом нумерованого списку",
    "Toggle heading for current line" : "Зробити рядок заголовком",
    "SHIFT" : "SHIFT",
    "Set the current line as a big heading" : "Зробити рядок великим заголовком",
    "Insert link" : "Вставити посилання",
    "Insert image" : "Додати зображення",
    "Switch between editor and viewer" : "Перемкнути редактор та переглядач",
    "Select folder to link to" : "Виберіть каталог",
    "All notes" : "Усі нотатки",
    "Categories" : "Категорії",
    "Create a sample note with Markdown" : "Створіть зразок примітки з Markdown",
    "No notes yet" : "Нотатки поки відсутні",
    "Upload image" : "Завантажити зображення",
    "Select an image" : "Виберіть зображення",
    "You cannot select images outside of your notes folder. Your notes folder is: {folder}" : "Ви не можете вибрати зображення за межами каталогу з нотатками. Ваш каталог нотаток: {folder}",
    "Wrong image" : "Недійсне зображення",
    "The file was not uploaded. Check your server logs." : "Файл не було завантажено. Перевірте журнали свого сервера.",
    "Install the app for your mobile phone in order to access your notes from everywhere." : "Встановіть мобільний застосунок для мобільного телефону, що дозволить отримувати доступ до нотаток звідусіль.",
    "Android app: {notes}" : "Додаток для Android: {notes}",
    "iOS app: {notes}" : "Додаток для iOS: {notes}",
    "Rich text editor" : "Редактор з форматуванням",
    "You can now switch to use the easy to use and distraction free rich text editor. It allows you to edit notes without seeing any Markdown marks." : "Ви можете почати використовувати простий у користуванні редактор форматованого тексту, який дозволить вводити текст без службових символів позначення форматування.",
    "This option can also be changed later on in the Notes app settings." : "Цю опцію можна буде змінити пізніше у налаштуваннях Нотаток.",
    "Keep plain Markdown editor" : "Використовувати простий редактор розмітки",
    "Use rich editor" : "Використовувати редактор з форматуванням",
    "Share" : "Share",
    "Change category" : "Змінити категорію",
    "Rename" : "Rename",
    "Rename note" : "Перейменувати нотатку",
    "Delete note" : "Вилучити нотатку",
    "Remove from favorites" : "Вилучено з улюбленого",
    "Add to favorites" : "Додати зірочку",
    "Error while renaming note." : "Помилка під час перейменування нотатки.",
    "Error during preparing note for deletion." : "Помилка під час підготовки нотатки до вилучення.",
    "The note has been changed in another session. Please choose which version should be saved." : "Нотатку було змінено в іншому сеансі. Будь ласка, виберіть, яку версію потрібно зберегти.",
    "Use version from server" : "Використовуйте віддалену версію",
    "Use current version" : "Використовувати поточну версію",
    "Empty note" : "Порожня записка",
    "Write …" : "Напишіть…",
    "CTRL + /" : "CTRL + /",
    "Edit" : "Редагувати",
    "Preview" : "Перегляд",
    "Exit full screen" : "Вийти з повноекранного режиму",
    "Full screen" : "Повноекранний режим",
    "Note is read-only. You cannot change it." : "Примітка доступна лише для читання. Ви не можете це змінити.",
    "Save failed. Click to retry." : "Не вдалося зберегти. Натисніть, щоб повторити спробу.",
    "Update conflict. Click for resolving manually." : "Конфлікт оновлень. Натисніть, щоб прийняти рішення вручну.",
    "Error from Nextcloud server: {msg}" : "Помилка сервера Nextcloud: {msg}",
    "Search for notes" : "Пошук нотаток",
    "Loading …" : "Завантаження...",
    "Find in all categories" : "Шукати в усіх категоріях",
    "Today" : "Сьогодні",
    "Yesterday" : "Вчора",
    "This week" : "Цього тижня",
    "Last week" : "Минулого тижня",
    "This month" : "Цього місяця",
    "Last month" : "Минулого місяця",
    "Use Markdown markups to style your text." : "Використовуйте розмітку Markdown, щоб стилізувати текст.",
    "Start writing a note by clicking on “{newnote}” in the app navigation." : "Почніть писати нотатку, натиснувши «{newnote}» ​​у навігаційній панелі програми.",
    "Note not found." : "Примітка не знайдена.",
    "Note is locked." : "Примітка заблокована.",
    "Insufficient storage." : "Недостатньо місця для зберігання.",
    "See JavaScript console and server log for details." : "Додаткову інформацію див. у консолі JavaScript і журналі сервера.",
    "Updating settings has failed." : "Не вдалося оновити налаштування.",
    "Fetching notes for dashboard has failed." : "Не вдалося отримати нотатки для інформаційної панелі.",
    "Fetching notes has failed." : "Помилка отримання нотаток.",
    "Fetching note {id} has failed." : "Не вдалося отримати нотатку {id}.",
    "Refreshing note {id} has failed." : "Не вдалося оновити нотатку {id}.",
    "Renaming note {id} has failed." : "Не вдалося перейменувати нотатку {id}.",
    "Creating new note has failed." : "Не вдалося створити нотатку.",
    "Saving note {id} has failed." : "Не вдалося зберегти нотатку {id}.",
    "Updating title for note {id} has failed." : "Помилка оновлення назви нотатки {id}.",
    "Undo delete has failed for note {title}." : "Не вдалося скасувати вилучення нотатки {title}.",
    "Deleting note {id} has failed." : "Не вдалося вилучити нотатку {id}.",
    "Toggling favorite for note {id} has failed." : "Помилка перемикання вподобаних нотаток {id}.",
    "Updating the note's category has failed. Is the target directory writable?" : "Не вдалося оновити категорію нотатки. Чи доступний цільовий каталог для запису?",
    "Updating the category for note {id} has failed." : "Не вдалося оновити категорію для примітки {id}.",
    "Uncategorized" : "Некатегоризоване",
    "Sample note" : "Приклад нотатки",
    "15 January 2021, via Nextcloud Notes" : "15 січня 2021 р., у Нотатках Nextcloud",
    "Me, you, and all our friends!" : "Я, ти та всі наші друзі!",
    "Tasks" : "Завдання",
    "Write nice todo lists" : "Написати зручний список справ",
    "Buy Fries" : "Купити пиріжків",
    "Birthdays" : "Дні народження",
    "Jen, in three days!" : "Петро, через три дні!",
    "Moss, 21.03.1973" : "Іванка, 21.03.1973",
    "Roy, 1979" : "Роман, 1979",
    "Review Steps" : "Переглянути послідовність кроків",
    "Turn PC off" : "Вимкнути комп'ютер",
    "Turn PC on" : "Увімкнути комп'ютер",
    "Then call IT" : "Далі зателефонуйте до служби підтримки",
    "Quotes" : "Цитати",
    "Nextcloud, a safe home for all your data" : "Хмара у Nextcloud, безпечний простір для ваших даних",
    "Development Mode" : "Режим розробки",
    "It looks that the notes app was installed from a development source. Please install it from the official <a href=\"%1$s\">Nextcloud App Store</a> instead. If you want to build the Notes app by yourself, please follow the <a href=\"%2$s\">developer instructions</a>." : "Схоже, застосунок для нотаток було встановлено з джерела розробки. Установіть його з офіційного <a href=\"%1$s\">каталогу застосунків Nextcloud</a>. Якщо ви хочете збілдити застосунок \"Нотатки\" самостійно, дотримуйтесь <a href=\"%2$s\">інструкцій розробника</a>."
},
"nplurals=4; plural=(n % 1 == 0 && n % 10 == 1 && n % 100 != 11 ? 0 : n % 1 == 0 && n % 10 >= 2 && n % 10 <= 4 && (n % 100 < 12 || n % 100 > 14) ? 1 : n % 1 == 0 && (n % 10 ==0 || (n % 10 >=5 && n % 10 <=9) || (n % 100 >=11 && n % 100 <=14 )) ? 2: 3);");
